# -*- coding: utf-8 -*-
import datetime

from datetime import time

from django.conf import settings
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext as ugt
from django import forms
from django.contrib.auth.models import User

from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jumbo.forms.models import AdminModelForm, ModelForm
from jumbo.core.urlresolvers import reverse

from asterisk.models import AsteriskProfile, AsteriskAddressBook, Settings, Cdr, Record
from asterisk.models import Fare, UnitCost, Prefix
from asterisk import views as asterisk_views

## FORM
class CdrAdminSearchForm(ModelForm):
    class Meta:
        model          = Cdr
        fields         = ('src', 'dst', 'dcontext')
        display_fields = (('src', 'dst',),
                          ('calldate__year','search_in_all_years'),
                          'duration__gte', 'dcontext',
                         )


    def __init__(self, *args, **kws):
        super(CdrAdminSearchForm, self).__init__(*args, **kws)
        self.fields['duration__gte'] = forms.IntegerField(label    = 'Total Call Time >', required = False)
        self.fields['search_in_all_years'] = forms.BooleanField(label=_("Search In All Years"), required=False)
        self.fields['calldate__year'] = forms.CharField(label=_("Year"), required=False)

    # Modifico il filtro di ricerca in modo da filtrare sempre in base all'anno corrente, tranne nel caso in cui
    # nei parametri di ricerca venga specificato un anno oppure venga flaggata la checkbox search_in_all_years
    def change_search_filter(self, lookup_params, qs):
        if not lookup_params.has_key('calldate__year') and not lookup_params.has_key('search_in_all_years'):
            qs = qs.filter(calldate__year = datetime.date.today().year)

        if lookup_params.has_key('search_in_all_years'):
            del lookup_params['search_in_all_years']
        return lookup_params, qs


class CdrAdmin(ExtendibleModelAdmin):
    class Media:
        css = {
            "all" : ("asterisk/css/admin_asterisk.css",)
        }

    save_on_top      = True
    list_display     = ('calldate', 'get_src', 'dst', 'dcontext', 'duration', 'billsec','callcost')
    default_group_by = '-calldate_date'
    search_form      = CdrAdminSearchForm
    actions          = None


    def get_urls(self):
        # Faccio in modo che nessun utente (neanche uno superuser) possa
        # inserire o modificare le telefonate dell'asterisk
        from django.conf.urls.defaults import patterns, url
        urls = super(CdrAdmin, self).get_urls()
        info = self.model._meta.app_label, self.model._meta.module_name

        my_urls = patterns('',
            url(r'^add/$',
                self.admin_site.admin_view(self.changelist_view),
                name='%s_%s_add' % info),
            url(r'^(.+)/$',
                self.admin_site.admin_view(self.changelist_view),
                name='%s_%s_change' % info),
        )
        return my_urls + urls


    def get_nome_interno(self, id):
        nome = ""
        if id.find("<") > -1:
            nome = id.split("<")[0]
        return nome.strip()


    def get_src(self, obj):
        nome = self.get_nome_interno(obj.clid)
        if nome:
            return "%s (%s)" % (obj.src, nome)
        else:
            return obj.src
    get_src.short_description = _("Caller")
    get_src.allow_tags        = True
    get_src.admin_order_field = 'src'


#    def get_link_click_to_call(self, field):
#        if field.isdigit():
#            return "<a href='#' onclick='confirmCall(%s)' class='click_to_call'>%s</a>" % (field, field)
#        return field

#    def get_calldatetime(self, obj):
#        return obj.calldate.strftime("%d/%m/%Y %H:%M")
#    get_calldatetime.short_description = _("Call Date")
#    get_calldatetime.allow_tags = True

#    def get_calldate(self, obj):
#        return obj.calldate.strftime("%d/%m/%Y")

#    def get_dst(self, obj):
#        return self.get_link_click_to_call(obj.dst)
#    get_dst.short_description = _("Called")
#    get_dst.allow_tags = True

#    def get_duration(self, obj):
#        return obj.duration
#    get_duration.short_description = _("Total Duration")
#    get_duration.allow_tags = True

#    def get_billsec(self, obj):
#        return obj.billsec
#    get_billsec.short_description = _("Call Duration")
#    get_billsec.allow_tags = True

## FORM
class RecordAdminSearchForm(ModelForm):
    class Meta:
        model          = Record
        fields         = ('ts_date', 'caller', 'callee')
        display_fields = (('ts_date', 'caller', 'callee'),)


class RecordAdmin(ExtendibleModelAdmin):
    class Meta:
        model = Record

    list_display = ('ts', 'caller', 'callee', 'get_recall')
    default_group_by = '-ts_date'
    actions          = None
    search_form      = RecordAdminSearchForm

    def get_recall(self, obj):
        return '<a href="%(url)s" title="%(description)s"><img src="%(media_url)sadmin/images/download.gif" alt="%(description)s" title="%(description)s"/></a>' % {'url': obj.recall.url,
                 'media_url': settings.MEDIA_URL,
                 'description': ugt('Download Record')
                }
    get_recall.short_description = _('Record')
    get_recall.allow_tags = True


class AsteriskProfileAdmin(ExtendibleModelAdmin):
    list_display = ('user', 'description', 'internal_number', 'get_edit_icon')
    fieldsets    = (
                   (_('general admin'), {'fields': (('user', 'description', 'internal_number'),)}),
                   )


class AsteriskAddressBookAdmin(ExtendibleModelAdmin):
    #list_display = ('description', 'phone_number','user')
    fieldsets = (
        (_('general admin'), {'fields': (('description', 'phone_number','user','is_internal'),)}),
    )

############################
# INLINE                   #
############################
class UnitCostInline(admin.TabularInline):
    model  = UnitCost
    extra  = 0
    fields = ('name', 'cost', 'hour_from', 'hour_to')

class PrefixAdmin(ExtendibleModelAdmin):
    list_display = ['prefix', 'description', 'get_edit_icon', 'get_delete_icon']
    fieldsets = (
        (_('logs admin'), {
            'fields'  : ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (None, {
            'fields'  : (
                'prefix',
                'description',
            )
        })
       )

class FareAdmin(ExtendibleModelAdmin):
    inlines = [UnitCostInline]
    list_display = ['name', 'connection_fee', 'symbol_currency', 'get_edit_icon', 'get_delete_icon']
    fieldsets = (
        (_('logs admin'), {
            'fields'  : ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (None, {
            'fields'  : (
                'prefix',
                'name',
                'connection_fee',
                'symbol_currency'
            )
        })
       )

    def get_urls(self):
        from django.conf.urls.defaults import patterns, url
        urls = super(FareAdmin, self).get_urls()
        my_urls = patterns('',
            url(r'^report/$'  , self.admin_site.admin_view(asterisk_views.report_centro_costo)
                              , name='asterisk_centro_costo_report'),
        )
        return my_urls + urls


admin.site.register(Settings, SettingsAdmin)
admin.site.register(Cdr, CdrAdmin)
admin.site.register(Record, RecordAdmin)
admin.site.register(AsteriskProfile, AsteriskProfileAdmin)
admin.site.register(AsteriskAddressBook, AsteriskAddressBookAdmin)
admin.site.register(Fare, FareAdmin)
admin.site.register(Prefix, PrefixAdmin)
